==> resin-4.0.53-sources.jar: com/caucho/boot/BootCommand.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.boot;


public interface BootCommand {
  public boolean isProOnly();

  public String getName();
  
  public String getDescription();

  public int doCommand(ResinBoot resinBoot, WatchdogArgs args)
    throws BootArgumentException;

  public boolean isRetry();

  public boolean isValueOption(String key);

  public boolean isIntValueOption(String key);

  public boolean isFlag(String key);

  public boolean isDefaultArgsAccepted();

  public void usage(boolean verbose);
  
  public boolean isStart();
  public boolean isStartAll();
  public boolean isShutdown();
  public boolean isConsole();

  public boolean isRemote(WatchdogArgs args);

  public void doWatchdogStart(WatchdogManager manager);
}

==> resin-4.0.66-sources.jar: com/caucho/boot/BootCommand.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.boot;


public interface BootCommand
{
  public static final int BOOT_OK = 0;
  public static final int BOOT_FAIL_PERM = 1;
  public static final int BOOT_FAIL_RETRY = 2;
  
  public boolean isProOnly();

  public String getName();
  
  public String getDescription();

  public int doCommand(ResinBoot resinBoot, WatchdogArgs args)
    throws BootArgumentException;

  public boolean isRetry();
  public int retryCount();

  public boolean isValueOption(String key);

  public boolean isIntValueOption(String key);

  public boolean isFlag(String key);

  public boolean isDefaultArgsAccepted();

  public void usage(boolean verbose);
  
  public boolean isStart();
  public boolean isStartAll();
  public boolean isShutdown();
  public boolean isConsole();

  public boolean isRemote(WatchdogArgs args);

  public void doWatchdogStart(WatchdogManager manager);
  
  enum ResultCommand {
    OK,
    FAIL_PERM,
    FAIL_RETRY;
  }
}
